@@ -38,7 +38,7 @@ type CloudFunctionGenerator struct {
 func (g CloudFunctionGenerator) loadPackages(namespace, pkgName string) terraformutils.Resource {
 	resource := terraformutils.NewResource(
 		fmt.Sprintf("%s:%s", namespace, pkgName),
-		pkgName,
+		normalizeResourceName(pkgName, true),
 		"ibm_function_package",
 		"ibm",
 		map[string]string{},
@@ -50,7 +50,7 @@ func (g CloudFunctionGenerator) loadPackages(namespace, pkgName string) terrafor
 func (g CloudFunctionGenerator) loadRules(namespace, ruleName string) terraformutils.Resource {
 	resource := terraformutils.NewResource(
 		fmt.Sprintf("%s:%s", namespace, ruleName),
-		normalizeResourceName(ruleName, false),
+		normalizeResourceName(ruleName, true),
 		"ibm_function_rule",
 		"ibm",
 		map[string]string{},
@@ -62,7 +62,7 @@ func (g CloudFunctionGenerator) loadRules(namespace, ruleName string) terraformu
 func (g CloudFunctionGenerator) loadTriggers(namespace, triggerName string) terraformutils.Resource {
 	resource := terraformutils.NewResource(
 		fmt.Sprintf("%s:%s", namespace, triggerName),
-		normalizeResourceName(triggerName, false),
+		normalizeResourceName(triggerName, true),
 		"ibm_function_trigger",
 		"ibm",
 		map[string]string{},
@@ -185,7 +185,7 @@ func (g *CloudFunctionGenerator) InitResources() error {
 				actionID = fmt.Sprintf("%s/%s", parts[1], a.Name)
 				g.Resources = append(g.Resources, terraformutils.NewResource(
 					fmt.Sprintf("%s:%s", n.GetName(), actionID),
-					normalizeResourceName(a.Name, false),
+					normalizeResourceName(a.Name, true),
 					"ibm_function_action",
 					"ibm",
 					map[string]string{},
@@ -196,7 +196,7 @@ func (g *CloudFunctionGenerator) InitResources() error {
 			} else {
 				g.Resources = append(g.Resources, terraformutils.NewResource(
 					fmt.Sprintf("%s:%s", n.GetName(), a.Name),
-					normalizeResourceName(a.Name, false),
+					normalizeResourceName(a.Name, true),
 					"ibm_function_action",
 					"ibm",
 					map[string]string{},
