@@ -608,46 +608,48 @@ func (g *FirewallNetworkingGenerator) PostConvertHook() error {
 	mapIPSECCryptoProfileNames := map[string]string{}
 
 	for _, r := range g.Resources {
-		if r.InstanceInfo.Type == "panos_aggregate_interface" {
-			mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-			mapInterfaceModes[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".mode}"
-		}
+		if _, ok := r.Item["name"]; ok {
+			if r.InstanceInfo.Type == "panos_aggregate_interface" {
+				mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+				mapInterfaceModes[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".mode}"
+			}
 
-		if r.InstanceInfo.Type == "panos_ethernet_interface" {
-			mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-			mapInterfaceModes[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".mode}"
-		}
+			if r.InstanceInfo.Type == "panos_ethernet_interface" {
+				mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+				mapInterfaceModes[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".mode}"
+			}
 
-		if r.InstanceInfo.Type == "panos_layer2_subinterface" {
-			mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+			if r.InstanceInfo.Type == "panos_layer2_subinterface" {
+				mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_layer3_subinterface" {
-			mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+			if r.InstanceInfo.Type == "panos_layer3_subinterface" {
+				mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_loopback_interface" {
-			mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+			if r.InstanceInfo.Type == "panos_loopback_interface" {
+				mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_tunnel_interface" {
-			mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+			if r.InstanceInfo.Type == "panos_tunnel_interface" {
+				mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_vlan_interface" {
-			mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+			if r.InstanceInfo.Type == "panos_vlan_interface" {
+				mapInterfaceNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_ike_crypto_profile" {
-			mapIKECryptoProfileNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+			if r.InstanceInfo.Type == "panos_ike_crypto_profile" {
+				mapIKECryptoProfileNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_ike_gateway" {
-			mapIKEGatewayNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+			if r.InstanceInfo.Type == "panos_ike_gateway" {
+				mapIKEGatewayNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_ipsec_crypto_profile" {
-			mapIPSECCryptoProfileNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			if r.InstanceInfo.Type == "panos_ipsec_crypto_profile" {
+				mapIPSECCryptoProfileNames[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 		}
 	}
 
@@ -655,7 +657,9 @@ func (g *FirewallNetworkingGenerator) PostConvertHook() error {
 		if r.InstanceInfo.Type == "panos_bgp" ||
 			r.InstanceInfo.Type == "panos_redistribution_profile_ipv4" ||
 			r.InstanceInfo.Type == "panos_static_route_ipv4" {
-			r.Item["virtual_router"] = "${panos_virtual_router." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".name}"
+			if _, ok := r.Item["virtual_router"]; ok {
+				r.Item["virtual_router"] = "${panos_virtual_router." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".name}"
+			}
 		}
 
 		if r.InstanceInfo.Type == "panos_bgp_aggregate" ||
@@ -666,58 +670,80 @@ func (g *FirewallNetworkingGenerator) PostConvertHook() error {
 			r.InstanceInfo.Type == "panos_bgp_import_rule_group" ||
 			r.InstanceInfo.Type == "panos_bgp_peer_group" ||
 			r.InstanceInfo.Type == "panos_bgp_redist_rule" {
-			r.Item["virtual_router"] = "${panos_bgp." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".virtual_router}"
+			if _, ok := r.Item["virtual_router"]; ok {
+				r.Item["virtual_router"] = "${panos_bgp." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".virtual_router}"
+			}
 		}
 
 		if r.InstanceInfo.Type == "panos_bgp_aggregate_advertise_filter" ||
 			r.InstanceInfo.Type == "panos_bgp_aggregate_suppress_filter" {
-			r.Item["virtual_router"] = "${panos_bgp_aggregate." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".virtual_router}"
-			r.Item["bgp_aggregate"] = "${panos_bgp_aggregate." + normalizeResourceName(r.Item["bgp_aggregate"].(string)) + ".name}"
+			if _, ok := r.Item["virtual_router"]; ok {
+				r.Item["virtual_router"] = "${panos_bgp_aggregate." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".virtual_router}"
+			}
+			if _, ok := r.Item["bgp_aggregate"]; ok {
+				r.Item["bgp_aggregate"] = "${panos_bgp_aggregate." + normalizeResourceName(r.Item["bgp_aggregate"].(string)) + ".name}"
+			}
 		}
 
 		if r.InstanceInfo.Type == "panos_bgp_peer" {
-			r.Item["virtual_router"] = "${panos_bgp." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".virtual_router}"
-			r.Item["peer_as"] = "${panos_bgp." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".as_number}"
+			if _, ok := r.Item["virtual_router"]; ok {
+				r.Item["virtual_router"] = "${panos_bgp." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".virtual_router}"
+				r.Item["peer_as"] = "${panos_bgp." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".as_number}"
+			}
 		}
 
 		if r.InstanceInfo.Type == "panos_bgp_conditional_adv_advertise_filter" ||
 			r.InstanceInfo.Type == "panos_bgp_conditional_adv_non_exist_filter" {
-			r.Item["virtual_router"] = "${panos_bgp." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".virtual_router}"
-			r.Item["bgp_conditional_adv"] = "${panos_bgp_conditional_adv." + normalizeResourceName(r.Item["panos_bgp_conditional_adv"].(string)) + ".name}"
+			if _, ok := r.Item["virtual_router"]; ok {
+				r.Item["virtual_router"] = "${panos_bgp." + normalizeResourceName(r.Item["virtual_router"].(string)) + ".virtual_router}"
+			}
+			if _, ok := r.Item["panos_bgp_conditional_adv"]; ok {
+				r.Item["bgp_conditional_adv"] = "${panos_bgp_conditional_adv." + normalizeResourceName(r.Item["panos_bgp_conditional_adv"].(string)) + ".name}"
+			}
 		}
 
 		if r.InstanceInfo.Type == "panos_gre_tunnel" {
-			r.Item["interface"] = mapInterfaceNames[r.Item["interface"].(string)]
-			r.Item["tunnel_interface"] = mapInterfaceNames[r.Item["tunnel_interface"].(string)]
+			if mapExists(mapInterfaceNames, r.Item, "interface") {
+				r.Item["interface"] = mapInterfaceNames[r.Item["interface"].(string)]
+			}
+			if mapExists(mapInterfaceNames, r.Item, "tunnel_interface") {
+				r.Item["tunnel_interface"] = mapInterfaceNames[r.Item["tunnel_interface"].(string)]
+			}
 		}
 
 		if r.InstanceInfo.Type == "panos_ike_gateway" {
-			if _, ok := r.Item["ikev1_crypto_profile"]; ok {
+			if mapExists(mapIKECryptoProfileNames, r.Item, "ikev1_crypto_profile") {
 				r.Item["ikev1_crypto_profile"] = mapIKECryptoProfileNames[r.Item["ikev1_crypto_profile"].(string)]
 			}
 		}
 
 		if r.InstanceInfo.Type == "panos_ipsec_tunnel" {
-			r.Item["tunnel_interface"] = mapInterfaceNames[r.Item["tunnel_interface"].(string)]
-			r.Item["ak_ike_gateway"] = mapIKEGatewayNames[r.Item["ak_ike_gateway"].(string)]
-			if _, ok := r.Item["ak_ipsec_crypto_profile"]; ok {
+			if mapExists(mapInterfaceNames, r.Item, "tunnel_interface") {
+				r.Item["tunnel_interface"] = mapInterfaceNames[r.Item["tunnel_interface"].(string)]
+			}
+			if mapExists(mapIKEGatewayNames, r.Item, "ak_ike_gateway") {
+				r.Item["ak_ike_gateway"] = mapIKEGatewayNames[r.Item["ak_ike_gateway"].(string)]
+			}
+			if mapExists(mapIPSECCryptoProfileNames, r.Item, "ak_ipsec_crypto_profile") {
 				r.Item["ak_ipsec_crypto_profile"] = mapIPSECCryptoProfileNames[r.Item["ak_ipsec_crypto_profile"].(string)]
 			}
 		}
 
 		if r.InstanceInfo.Type == "panos_ipsec_tunnel_proxy_id_ipv4" {
-			r.Item["tunnel_interface"] = mapInterfaceNames[r.Item["tunnel_interface"].(string)]
+			if mapExists(mapInterfaceNames, r.Item, "ipsec_tunnel") {
+				r.Item["ipsec_tunnel"] = mapInterfaceNames[r.Item["ipsec_tunnel"].(string)]
+			}
 		}
 
 		if r.InstanceInfo.Type == "panos_layer2_subinterface" {
-			if _, ok := mapInterfaceModes[r.Item["parent_interface"].(string)]; ok {
+			if mapExists(mapInterfaceModes, r.Item, "parent_interface") {
 				r.Item["parent_mode"] = mapInterfaceModes[r.Item["parent_interface"].(string)]
 			}
 		}
 
 		if r.InstanceInfo.Type == "panos_layer2_subinterface" ||
 			r.InstanceInfo.Type == "panos_layer3_subinterface" {
-			if _, ok := mapInterfaceNames[r.Item["parent_interface"].(string)]; ok {
+			if mapExists(mapInterfaceNames, r.Item, "parent_interface") {
 				r.Item["parent_interface"] = mapInterfaceNames[r.Item["parent_interface"].(string)]
 			}
 		}
@@ -765,9 +791,11 @@ func (g *FirewallNetworkingGenerator) PostConvertHook() error {
 			if _, ok := r.Item["interfaces"]; ok {
 				interfaces := make([]string, len(r.Item["interfaces"].([]interface{})))
 				for k, eth := range r.Item["interfaces"].([]interface{}) {
-					if name, ok := mapInterfaceNames[eth.(string)]; ok {
+					if name, ok2 := mapInterfaceNames[eth.(string)]; ok2 {
 						interfaces[k] = name
+						continue
 					}
+					interfaces[k] = eth.(string)
 				}
 
 				r.Item["interfaces"] = interfaces
@@ -775,7 +803,9 @@ func (g *FirewallNetworkingGenerator) PostConvertHook() error {
 		}
 
 		if r.InstanceInfo.Type == "panos_vlan" {
-			r.Item["vlan_interface"] = mapInterfaceNames[r.Item["vlan_interface"].(string)]
+			if mapExists(mapInterfaceNames, r.Item, "vlan_interface") {
+				r.Item["vlan_interface"] = mapInterfaceNames[r.Item["vlan_interface"].(string)]
+			}
 		}
 	}
 
