@@ -259,16 +259,18 @@ func (g *FirewallObjectsGenerator) PostConvertHook() error {
 	mapServiceObjectIDs := map[string]string{}
 
 	for _, r := range g.Resources {
-		if r.InstanceInfo.Type == "panos_address_object" {
-			mapAddressObjectIDs[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+		if _, ok := r.Item["name"]; ok {
+			if r.InstanceInfo.Type == "panos_address_object" {
+				mapAddressObjectIDs[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_application_object" {
-			mapApplicationObjectIDs[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
-		}
+			if r.InstanceInfo.Type == "panos_application_object" {
+				mapApplicationObjectIDs[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 
-		if r.InstanceInfo.Type == "panos_service_object" {
-			mapServiceObjectIDs[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			if r.InstanceInfo.Type == "panos_service_object" {
+				mapServiceObjectIDs[r.Item["name"].(string)] = "${" + r.InstanceInfo.Type + "." + r.ResourceName + ".name}"
+			}
 		}
 	}
 
@@ -277,7 +279,11 @@ func (g *FirewallObjectsGenerator) PostConvertHook() error {
 			if _, ok := r.Item["static_addresses"]; ok {
 				staticAddresses := make([]string, len(r.Item["static_addresses"].([]interface{})))
 				for k, staticAddress := range r.Item["static_addresses"].([]interface{}) {
-					staticAddresses[k] = mapAddressObjectIDs[staticAddress.(string)]
+					if _, ok2 := mapAddressObjectIDs[staticAddress.(string)]; ok2 {
+						staticAddresses[k] = mapAddressObjectIDs[staticAddress.(string)]
+						continue
+					}
+					staticAddresses[k] = staticAddress.(string)
 				}
 
 				r.Item["static_addresses"] = staticAddresses
@@ -288,7 +294,7 @@ func (g *FirewallObjectsGenerator) PostConvertHook() error {
 			if _, ok := r.Item["applications"]; ok {
 				applications := make([]string, len(r.Item["applications"].([]interface{})))
 				for k, application := range r.Item["applications"].([]interface{}) {
-					if _, ok := mapApplicationObjectIDs[application.(string)]; ok {
+					if _, ok2 := mapApplicationObjectIDs[application.(string)]; ok2 {
 						applications[k] = mapApplicationObjectIDs[application.(string)]
 						continue
 					}
@@ -300,12 +306,18 @@ func (g *FirewallObjectsGenerator) PostConvertHook() error {
 		}
 
 		if r.InstanceInfo.Type == "panos_service_group" {
-			services := make([]string, len(r.Item["services"].([]interface{})))
-			for k, service := range r.Item["services"].([]interface{}) {
-				services[k] = mapServiceObjectIDs[service.(string)]
-			}
+			if _, ok := r.Item["services"]; ok {
+				services := make([]string, len(r.Item["services"].([]interface{})))
+				for k, service := range r.Item["services"].([]interface{}) {
+					if _, ok2 := mapServiceObjectIDs[service.(string)]; ok2 {
+						services[k] = mapServiceObjectIDs[service.(string)]
+						continue
+					}
+					services[k] = service.(string)
+				}
 
-			r.Item["services"] = services
+				r.Item["services"] = services
+			}
 		}
 	}
 
